#!/bin/bash
MIN_FREE=$1
DIRECTORY=$2
PRESERVE1=$3
PRESERVE2=$4

echo "Starting cleanup-logfile.sh ..."

mkdir -p $DIRECTORY
cd $DIRECTORY

mkdir -p processdata
mkdir -p changelog

echo "Cleaning process data cache files older than 28 days."
cd processdata
for file in $(find . -maxdepth 1 -regex '.*\.processdata.*$' -mtime +28)
do
    echo "Deleting file: $file"
    rm $file
done
cd ..

echo "Cleaning changelog cache files older than 28 days."
cd changelog 
for file in $(find . -maxdepth 1 -regex '.*\.changelog.*$' -mtime +28)
do
    echo "Deleting file: $file"
    rm $file
done
cd ..

DIMENSION=$(df $PWD | awk '/[0-9]%/{print $(NF-2)}')

if [ $DIMENSION -lt $MIN_FREE ]
then
    echo "Cleaning up parameter logs..."
    for file in $(find . -maxdepth 1 -regex '.*\.parameters\.log.*$' -not -regex "\./$PRESERVE1\.parameters\.log.*?$" -not -regex "\./$PRESERVE2\.parameters\.log.*?$" -printf "%T+ %p\0" | sort -z | sed -z 's/^[^ ]* //' | tr '\0' '\n')
    do
        echo "Deleting file: $file"
        rm $file
        DIMENSION=$(df $PWD | awk '/[0-9]%/{print $(NF-2)}')
        if [ $DIMENSION -ge $MIN_FREE ]
        then
            break
        fi
    done
else
    echo "No cleanup of parameter log files needed."
fi